@@ -1,12 +1,12 @@
-#tested
+#not working
 
 import inspect
 import sqlite3
 from inspect import getframeinfo
 from inspect import stack
 
-class view:
-    def __init__(self, user_ID=None):
+class Disecon_view:
+    def __init__(self, user_ID:int =None):
         self.user_ID = user_ID
         
     def wallet(self):                    
